==> odoo_19.1a1.20251203.zip: odoo-19.1a1.post20251203/odoo/addons/web/static/src/views/view_components/multi_currency_popover.js <==
import { Component, onWillStart, useExternalListener, useState } from "@odoo/owl";
import { getCurrency, getCurrencyRates } from "@web/core/currency";
import { toLocaleDateString } from "@web/core/l10n/dates";
import { user } from "@web/core/user";
import { useService } from "@web/core/utils/hooks";
import { formatMonetary } from "../fields/formatters";

export class MultiCurrencyPopover extends Component {
    static template = "web.MultiCurrencyPopover";
    static props = {
        close: Function,
        currencyIds: Array,
        target: HTMLElement,
        value: Number,
    };

    setup() {
        this.orm = useService("orm");
        this.defaultCurrency = user.activeCompany.currency_id;
        this.state = useState({ rates: null });
        onWillStart(async () => {
            this.state.rates = await getCurrencyRates();
        });
        useExternalListener(window, "mouseover", (ev) => {
            if (ev.target !== this.props.target) {
                this.props.close();
            }
        });
    }

    get currencies() {
        return this.props.currencyIds.reduce((currencies, currencyId) => {
            if (currencyId && currencyId !== this.defaultCurrency) {
                currencies.push({
                    ...getCurrency(currencyId),
                    id: currencyId,
                    rate: this.state.rates[currencyId].rate,
                    date: toLocaleDateString(this.state.rates[currencyId].date),
                    value: this.props.value / this.state.rates[currencyId].rate,
                });
            }
            return currencies;
        }, []);
    }

    formatedValue(value, currencyId) {
        return formatMonetary(value, { currencyId });
    }
}

==> odoo_19.2a1.20260208.zip: odoo-19.2a1.post20260208/odoo/addons/web/static/src/views/view_components/multi_currency_popover.js <==
import { Component, onWillStart, useExternalListener, useState } from "@odoo/owl";
import { getCurrency, getCurrencyRates } from "@web/core/currency";
import { toLocaleDateString } from "@web/core/l10n/dates";
import { user } from "@web/core/user";
import { useService } from "@web/core/utils/hooks";
import { formatMonetary } from "../fields/formatters";

export class MultiCurrencyPopover extends Component {
    static template = "web.MultiCurrencyPopover";
    static props = {
        close: Function,
        currencyIds: Array,
        target: HTMLElement,
        value: Number,
    };

    setup() {
        this.orm = useService("orm");
        this.defaultCurrency = user.activeCompany.currency_id;
        this.state = useState({ rates: null });
        onWillStart(async () => {
            this.state.rates = await getCurrencyRates();
        });
        useExternalListener(window, "mouseover", (ev) => {
            if (ev.target !== this.props.target) {
                this.props.close();
            }
        });
    }

    get currencies() {
        return this.props.currencyIds.reduce((currencies, currencyId) => {
            if (currencyId && currencyId !== this.defaultCurrency && getCurrency(currencyId)) {
                currencies.push({
                    ...getCurrency(currencyId),
                    id: currencyId,
                    rate: this.state.rates[currencyId].rate,
                    date: toLocaleDateString(this.state.rates[currencyId].date),
                    value: this.props.value / this.state.rates[currencyId].rate,
                });
            }
            return currencies;
        }, []);
    }

    formatedValue(value, currencyId) {
        return formatMonetary(value, { currencyId });
    }
}
